/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/



#include	"version.h"


VERSION xl_lang_version = {
	"XL.lang",
	"XL",
	"(C) 2000-2002 Hirohisa Mori",
	"ver.0.1",
	2001,10,16,
	0,
	"XL language version"
};

VERSION xl_proto_version = {
	"XL.proto",
	"XL",
	"(C) 2000-2003 Hirohisa Mori",
	"ver.A.02.09",
	2002,9,19,
	0,
	"XL protocol version"
};


VERSION xl_code_version = {
	"XL.code",
	"XL",
	"(C) 2000-2003 Hirohisa Mori",
	"ver.A.02.10 (ASTROBOY)",
	2003,9,19,
	0,
	"version of XL code (src/xl)"
};



